@@ -517,3 +517,122 @@ def write(t, c, size=16, style=None, family=None):
     else:
         font = (f, size)
     t.write(c, font=font)
+
+
+@check_pen
+def tetris_CZ(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x - 50, y + 50)
+    square(t, size)
+    move(t, x, y + 50)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x + 50, y)
+    square(t, size)
+    move(t, x, y)
+
+
+@check_pen
+def tetris_RZ(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x + 50, y + 50)
+    square(t, size)
+    move(t, x, y + 50)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x - 50, y)
+    square(t, size)
+    move(t, x, y)
+
+
+@check_pen
+def tetris_OR(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x + 50, y + 50)
+    square(t, size)
+    move(t, x + 50, y)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x - 50, y)
+    square(t, size)
+    move(t, x, y)
+
+
+@check_pen
+def tetris_BR(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x - 50, y + 50)
+    square(t, size)
+    move(t, x - 50, y)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x + 50, y)
+    square(t, size)
+    move(t, x, y)
+
+
+@check_pen
+def tetris_H(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x, y + 50)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x, y - 50)
+    square(t, size)
+    move(t, x, y - 100)
+    square(t, size)
+    move(t, x, y - 100)
+
+
+@check_pen
+def tetris_T(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x - 50, y + 50)
+    square(t, size)
+    move(t, x, y + 50)
+    square(t, size)
+    move(t, x + 50, y + 50)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x, y)
+
+
+@check_pen
+def tetris_S(t, x=None, y=None, size=50):
+    if x is None:
+        x = t.xcor()
+    if y is None:
+        y = t.ycor()
+    move(t, x - 50, y + 50)
+    square(t, size)
+    move(t, x, y + 50)
+    square(t, size)
+    move(t, x - 50, y)
+    square(t, size)
+    move(t, x, y)
+    square(t, size)
+    move(t, x, y)
\ No newline at end of file
